@@ -14,6 +14,8 @@ from pathlib import Path
 
 import websockets
 from websockets.server import WebSocketServerProtocol
+from websockets.http import Headers
+from websockets.http11 import Response
 
 # Suppress noisy websockets handshake errors (TLS mismatch, etc.)
 logging.getLogger("websockets.server").setLevel(logging.ERROR)
@@ -191,6 +193,9 @@ class DarkCodeServer:
             self._bound_device_id = self.config.bound_device_id
             self._state = ServerState.LOCKED
 
+        # Web admin handler (lazy loaded)
+        self._web_admin = None
+
     def _generate_device_id(self, client_ip: str, user_agent: str = "", device_info: dict = None) -> str:
         """Generate a unique device fingerprint.
 
@@ -273,6 +278,72 @@ class DarkCodeServer:
                 self.config.save()
                 # Note: Old tokens valid for grace_hours
 
+    async def _process_request(self, connection, request):
+        """Process HTTP requests before WebSocket upgrade.
+
+        This allows serving the web admin dashboard on /admin while
+        still handling WebSocket connections on the same port.
+
+        Note: websockets 13+ passes (connection, request) instead of (path, headers)
+        and expects a Response object, not a tuple.
+        """
+        # Extract path and headers from the request object
+        # Handle both old and new websockets API
+        if hasattr(request, 'path'):
+            path = request.path
+            request_headers = request.headers
+        else:
+            # Old API - request is actually path string
+            path = str(connection) if isinstance(connection, str) else getattr(connection, 'path', '/')
+            request_headers = request if hasattr(request, 'get') else {}
+
+        # Handle admin dashboard requests (non-WebSocket HTTP)
+        if isinstance(path, str) and path.startswith('/admin'):
+            # Initialize web admin handler if needed
+            if self._web_admin is None:
+                try:
+                    from darkcode_server.web_admin import WebAdminHandler
+                    self._web_admin = WebAdminHandler(self.config, self)
+                except ImportError:
+                    return Response(404, "Not Found", Headers([]), b"Web admin not available")
+
+            # Determine HTTP method and gather request info
+            method = 'GET'  # Default
+            # Note: POST detection is limited in websockets process_request
+            # We'll use a workaround with content-length header
+            content_length = request_headers.get('Content-Length', '0')
+            if int(content_length) > 0:
+                method = 'POST'
+
+            # Build headers dict
+            headers = {str(k): str(v) for k, v in request_headers.items()}
+
+            # For POST requests, we can't easily get body in process_request
+            # So we handle it via query params or redirect to GET
+            body = b''
+
+            # Handle the request
+            status, resp_headers, resp_body = self._web_admin.handle_request(
+                path, method, headers, body
+            )
+
+            # Build Response object for websockets 13+
+            # Get status phrase
+            from http import HTTPStatus
+            try:
+                reason = HTTPStatus(status).phrase
+            except ValueError:
+                reason = "Unknown"
+
+            # Convert headers to Headers object
+            header_list = [(k, v) for k, v in resp_headers.items()]
+            response_headers = Headers(header_list)
+
+            return Response(status, reason, response_headers, resp_body)
+
+        # For WebSocket paths, return None to continue with upgrade
+        return None
+
     async def start(self):
         """Start the WebSocket server."""
         self._running = True
@@ -309,6 +380,7 @@ class DarkCodeServer:
             ssl=ssl_context,
             ping_interval=self.config.ping_interval,
             ping_timeout=self.config.ping_timeout,
+            process_request=self._process_request,  # Handle HTTP admin requests
         )
 
         # Start idle monitor if timeout is configured
@@ -927,6 +999,94 @@ class DarkCodeServer:
                         "status": "processing",
                     }))
 
+        elif msg_type == "send_message_with_files":
+            # Handle message with file attachments
+            text = msg.get("text", "")
+            files = msg.get("files", [])
+
+            # Validate
+            if not isinstance(text, str):
+                text = ""
+            if not isinstance(files, list):
+                files = []
+
+            # Process files - save them and build context
+            file_descriptions = []
+            saved_files = []
+
+            for file_info in files[:5]:  # Max 5 files
+                try:
+                    name = file_info.get("name", "file")
+                    content = file_info.get("content", "")
+                    is_base64 = file_info.get("isBase64", False)
+                    mime_type = file_info.get("mimeType", "application/octet-stream")
+
+                    # Sanitize filename
+                    safe_name = "".join(c for c in name if c.isalnum() or c in "._-")[:100]
+                    if not safe_name:
+                        safe_name = "uploaded_file"
+
+                    # Save to uploads subdirectory
+                    uploads_dir = session.working_dir / ".darkcode_uploads"
+                    uploads_dir.mkdir(exist_ok=True)
+
+                    file_path = uploads_dir / safe_name
+
+                    # Handle base64 vs text content
+                    if is_base64:
+                        import base64
+                        try:
+                            decoded = base64.b64decode(content)
+                            file_path.write_bytes(decoded)
+                        except Exception:
+                            continue
+                    else:
+                        file_path.write_text(content, encoding="utf-8")
+
+                    saved_files.append(str(file_path))
+
+                    # Build description for Claude
+                    if mime_type.startswith("image/"):
+                        file_descriptions.append(f"[Image attached: {safe_name} at {file_path}]")
+                    elif mime_type.startswith("text/") or not is_base64:
+                        # Include text content directly for Claude to see
+                        preview = content[:2000] if len(content) > 2000 else content
+                        file_descriptions.append(f"[File: {safe_name}]\n```\n{preview}\n```")
+                    else:
+                        file_descriptions.append(f"[Binary file attached: {safe_name} at {file_path}]")
+
+                except Exception as e:
+                    logger.warning(f"Failed to process file: {e}")
+                    continue
+
+            # Build the full message
+            full_message = text
+            if file_descriptions:
+                files_context = "\n\n".join(file_descriptions)
+                if text:
+                    full_message = f"{text}\n\n--- Attached Files ---\n{files_context}"
+                else:
+                    full_message = f"--- Attached Files ---\n{files_context}"
+
+            if full_message:
+                if await self._write_to_process(session, full_message):
+                    session.is_processing = True
+                    session.last_active = time.time()
+                    session.message_count += 1
+
+                    # Save to chat history
+                    if session.chat_session_id:
+                        self._chat_history.save_message(session.chat_session_id, {
+                            "role": "user",
+                            "content": text if text else "(files attached)",
+                            "files": saved_files,
+                        })
+
+                    await session.websocket.send(json.dumps({
+                        "type": "status",
+                        "status": "processing",
+                    }))
+
         elif msg_type == "abort":
             if session.process and self._is_process_alive(session):
                 try:
